@@ -1,7 +1,7 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 
 /*
- *  File-Roller
+ *  gThumb
  *
  *  Copyright (C) 2001, 2002 The Free Software Foundation, Inc.
  *
@@ -42,6 +42,8 @@
    Authors: Ramiro Estrugo <ramiro@eazel.com>
 */
 
+/* Modified by Paolo Bacchilega <paolo.bacch@tin.it> for gThumb. */
+
 #ifndef GCONF_UTILS_H
 #define GCONF_UTILS_H
 
@@ -59,30 +61,41 @@ void         eel_global_client_free          (void);
 
 gboolean     eel_gconf_handle_error          (GError                **error);
 
+gboolean     eel_gconf_get_boolean           (const char             *key,
+					      gboolean                def_val);
+
 void         eel_gconf_set_boolean           (const char             *key,
-					      gboolean                boolean_value);
+					      gboolean                value);
 
-gboolean     eel_gconf_get_boolean           (const char             *key);
-
-int          eel_gconf_get_integer           (const char             *key);
+int          eel_gconf_get_integer           (const char             *key,
+					      int                     def_val);
 
 void         eel_gconf_set_integer           (const char             *key,
-					      int                     int_value);
+					      int                     value);
 
-float        eel_gconf_get_float             (const char             *key);
+float        eel_gconf_get_float             (const char             *key,
+					      float                   def_val);
 
 void         eel_gconf_set_float             (const char             *key,
-					      float                   float_value);
+					      float                   value);
 
-char *       eel_gconf_get_string            (const char             *key);
+char *       eel_gconf_get_string            (const char             *key,
+					      const char             *def_val);
 
 void         eel_gconf_set_string            (const char             *key,
-					      const char             *string_value);
+					      const char             *value);
 
-char *       eel_gconf_get_locale_string     (const char             *key);
+char *       eel_gconf_get_path              (const char             *key,
+					      const char             *def_val);
+
+void         eel_gconf_set_path              (const char             *key,
+					      const char             *value);
+
+char *       eel_gconf_get_locale_string     (const char             *key,
+					      const char             *def_val);
 
 void         eel_gconf_set_locale_string     (const char             *key,
-					      const char             *string_value);
+					      const char             *value);
 
 GSList *     eel_gconf_get_string_list       (const char             *key);
 
